@@ -4,7 +4,7 @@ methods that act upon a transfer function to gain functions such as the
 mass function.
 '''
 
-version = '1.0.4'
+version = '1.0.5'
 
 ###############################################################################
 # Some Imports
@@ -313,7 +313,7 @@ class Perturbations(object):
 
         print "Warning: No variables were updated!"
         for key, val in kwargs.iteritems():
-            if key not in set_transfer + set_kbounds + set_kbounds_extra_cosmo + set_WDM + set_z + self.camb_dict + self.extra_cosmo:
+            if key not in set_transfer + set_kbounds + set_kbounds_extra_cosmo + set_WDM + set_z + self.camb_dict.keys() + self.extra_cosmo.keys():
                 print "Warning: Variable entered (", key, ") is not a valid keyword"
             if key in self.__dict__:
                 if val == self.__dict__[key]:
